/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.avro.mapred;

/** The wrapper of data for jobs configured with {@link AvroJob} . */
public class AvroWrapper<T> {
  private T datum;

  /** Wrap null. Construct {@link AvroWrapper} wrapping no datum. */
  public AvroWrapper() {
    this(null);
  }

  /** Wrap a datum. */
  public AvroWrapper(T datum) {
    this.datum = datum;
  }

  /** Return the wrapped datum. */
  public T datum() {
    return datum;
  }

  /** Set the wrapped datum. */
  public void datum(T datum) {
    this.datum = datum;
  }

  @Override
  public int hashCode() {
    return (datum == null) ? 0 : datum.hashCode();
  }

  @Override
  public boolean equals(Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    AvroWrapper that = (AvroWrapper) obj;
    if (this.datum == null) {
      return that.datum == null;
    } else
      return datum.equals(that.datum);
  }

  /** Get the wrapped datum as JSON. */
  @Override
  public String toString() {
    return datum.toString();
  }
}
